@@ -1,5 +1,5 @@
 import logging
-from flexget.plugin import get_plugins_by_group, register_plugin
+from flexget.plugin import get_plugins_by_group, register_plugin, DEFAULT_PRIORITY
 
 log = logging.getLogger('est_released')
 
@@ -19,10 +19,10 @@ class EstimateRelease(object):
         :return: estimated date of released for the entry, None if it can't figure it out
         """
 
-        log.info(entry['title'])
-        estimators = get_plugins_by_group('estimate_release')
-        for estimator in estimators:
-            estimate = estimator.instance.estimate(entry)
+        log.debug(entry['title'])
+        estimators = [e.instance.estimate for e in get_plugins_by_group('estimate_release')]
+        for estimator in sorted(estimators, key=lambda e: getattr(e, 'priority', DEFAULT_PRIORITY), reverse=True):
+            estimate = estimator(entry)
             # return first successful estimation
             if estimate is not None:
                 return estimate
